package javax.swing.text.html.parser;

import java.util.Enumeration;
import java.util.Hashtable;
import java.util.Vector;
import java.io.Serializable;

public final class AttributeList implements DTDConstants, Serializable
{
    public String name;
    public int type;
    public Vector<?> values;
    public int modifier;
    public String value;
    public AttributeList next;
    static Hashtable<Object, Object> attributeTypes;
    
    AttributeList() {
    }
    
    public AttributeList(String name) {
        this.name = name;
    }
    
    public AttributeList(String name, int type, int modifier, String value, Vector<?> values, AttributeList next) {
        this.name = name;
        this.type = type;
        this.modifier = modifier;
        this.value = value;
        this.values = values;
        this.next = next;
    }
    
    public String getName() {
        return this.name;
    }
    
    public int getType() {
        return this.type;
    }
    
    public int getModifier() {
        return this.modifier;
    }
    
    public Enumeration<?> getValues() {
        return (this.values != null) ? this.values.elements() : null;
    }
    
    public String getValue() {
        return this.value;
    }
    
    public AttributeList getNext() {
        return this.next;
    }
    
    @Override
    public String toString() {
        return this.name;
    }
    
    static void defineAttributeType(String s, int i) {
        Integer value = Integer.valueOf(i);
        AttributeList.attributeTypes.put(s, value);
        AttributeList.attributeTypes.put(value, s);
    }
    
    public static int name2type(String key) {
        Integer n = (Integer)AttributeList.attributeTypes.get(key);
        return (n == null) ? 1 : ((int)n);
    }
    
    public static String type2name(int i) {
        return (String)AttributeList.attributeTypes.get(Integer.valueOf(i));
    }
    
    static {
        AttributeList.attributeTypes = new Hashtable();
        defineAttributeType("CDATA", 1);
        defineAttributeType("ENTITY", 2);
        defineAttributeType("ENTITIES", 3);
        defineAttributeType("ID", 4);
        defineAttributeType("IDREF", 5);
        defineAttributeType("IDREFS", 6);
        defineAttributeType("NAME", 7);
        defineAttributeType("NAMES", 8);
        defineAttributeType("NMTOKEN", 9);
        defineAttributeType("NMTOKENS", 10);
        defineAttributeType("NOTATION", 11);
        defineAttributeType("NUMBER", 12);
        defineAttributeType("NUMBERS", 13);
        defineAttributeType("NUTOKEN", 14);
        defineAttributeType("NUTOKENS", 15);
        AttributeList.attributeTypes.put("fixed", Integer.valueOf(1));
        AttributeList.attributeTypes.put("required", Integer.valueOf(2));
        AttributeList.attributeTypes.put("current", Integer.valueOf(3));
        AttributeList.attributeTypes.put("conref", Integer.valueOf(4));
        AttributeList.attributeTypes.put("implied", Integer.valueOf(5));
    }
}
